% Copyright (C) 1995-2007 by Hiroshi Nakashima, Yasuki Saito and
%                            The Editorial Board of the IPSJ Journal
%
% ipsjpapers.cls 02-Jan-08 by Hiroshi Nakashima (ver 3.00)
% (revision history deleted)
% ipsjpapers.cls  1-Apr-96 by Hiroshi Nakashima (ver 2.00)

\ifx\pfmtname\undefined
\NeedsTeXFormat{LaTeX2e}
\else
\NeedsTeXFormat{pLaTeX2e}
\fi

\ProvidesClass{ipsjpapers}[2008/01/08 ver 3.00]
\input{ipsjpapers.sty}
\endinput
